////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     Host Communications Channel Module Internal
///
///     This file defines the internal HCC module function prototypes and
///     definitions.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

#include "tera_pcoip_hcc_apdu.h"

// ---- Constants and Types -------------------------------------------------

// --------------------------------------------------------------------------
//  sHCC_HMI_APDU_HDR
///     HMI APDU header
//
//  Description:
///     This structure defines the format of the HMI APDU header. This
///     header is only used when sending the APDU in a packet. The header
///     precedes the data, and contains the HMI command associated with the
///     data.
///
typedef struct sHCC_HMI_APDU_HDR_STRUCT
{
    UINT8 cmd;          ///< HMI command
    UINT8 unused[3];
} sHCC_HMI_APDU_HDR;

// --------------------------------------------------------------------------
//  sHCC_HMI_APDU_AVAIL_CMD
///     Available HMI commands APDU
//
//  Description:
///     This structure defines the format of the available HMI commands APDU.
///
typedef struct sHCC_HMI_APDU_AVAIL_CMD_STRUCT
{
    sHCC_HMI_APDU_HDR            hdr;
    sTERA_PCOIP_HCC_APDU_HMI_MAP data;
} sHCC_HMI_APDU_AVAIL_CMD;

// --------------------------------------------------------------------------
//  sHCC_HMI_APDU_VAR
///     HMI variable set/get APDU
//
//  Description:
///     This structure defines the format of the HMI variable set/get APDU.
///
typedef struct sHCC_HMI_APDU_VAR_STRUCT
{
    sHCC_HMI_APDU_HDR            hdr;
    sTERA_PCOIP_HCC_APDU_HMI_VAR data;
} sHCC_HMI_APDU_VAR;

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

