////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     Packet Module
///
///     This file defines the packet module API prototypes and definitions.
///     This module uses memory buffers from the memory module.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

// ---- Constants and Types -------------------------------------------------

// This macro is used to access the buffer of an allocated message
#define mTERA_MSG_BUF_GET(msg)  (void *)((UINT8 *)(msg) + sizeof(sTERA_MSG))

// --------------------------------------------------------------------------
//  sTERA_MSG
///     Message structure
//
//  Description:
///     This structure defines a message. Since the size of each message is not
///     known at compile time, this structure is more like a header. The
///     message buffer can be accessed via the macro. The users of the messages
///     must NOT modify any of the variables in this structure.
///
typedef struct sTERA_MSG_STRUCT
{
    struct sTERA_MSG_STRUCT *next;      ///< Next pointer
    void                    *handle;    ///< Pointer to buffer allocated from lookaside cache
    UINT32                   buf_len;   ///< Message buffer length
} sTERA_MSG;

// --------------------------------------------------------------------------
//  sTERA_MSG_Q
///     Message queue
//
//  Description:
///     This structure defines a packet queue. Each packet queue needs to be
///     initialized before it can be used.
///
typedef struct sTERA_MSG_Q_STRUCT
{
    INT         initialized;    ///< Initialized flag
    struct semaphore  lock;     ///< Message queue synchronization lock
    sTERA_MSG  *head;           ///< Pointer to head of packet queue
    UINT32      enqueue_cnt;    ///< Enqueue counter
    UINT32      dequeue_cnt;    ///< Dequeue counter
} sTERA_MSG_Q;

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

extern INT32 tera_msg_init(
    sMSG_CBLK *cblk,
    UINT32     max_msg_size,
    UINT32     dev_id
    );

extern void tera_msg_cleanup(
    sMSG_CBLK *cblk
    );

extern sTERA_MSG *tera_msg_alloc(
    struct pci_dev *dev,
    UINT32    buf_len,
    UINT32    num_msg
    );

extern void tera_msg_free(
    struct pci_dev *dev,
    sTERA_MSG *msg
    );

extern INT32 tera_msg_q_init(
    sTERA_MSG_Q *msg_q
    );

extern void tera_msg_q_purge(
    struct pci_dev *dev,
    sTERA_MSG_Q    *msg_q
    );

extern void tera_msg_q_enqueue(
    sTERA_MSG_Q *msg_q,
    sTERA_MSG   *msg
    );

extern void tera_msg_q_head_enqueue(
    sTERA_MSG_Q *msg_q,
    sTERA_MSG   *msg
    );

extern sTERA_MSG *tera_msg_q_dequeue(
    sTERA_MSG_Q *msg_q
    );

