////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     PCoIP HDC Device Ioctls
///
///     This file defines the PCoIP Host Data Channel (HDC) device
///     driver ioctls.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

#include "tera_pcoip_public.h"
#include "tera_pcoip_hdc_apdu.h"

// ---- Constants and Types -------------------------------------------------

//
// Macros to define ioctl codes for different HDC users (the IOCTL bit field
// format is defined in the file tera_pcoip_public.h)
//
#define mTERA_PCOIP_HDC_IOCTL_KMP(cmd) \
    mTERA_PCOIP_HDC_IOCTL(((TERA_PCOIP_HDC_APDU_USER_KMP & 0x7) << 5) | \
                          (cmd & 0x1F))

//
// KMP ioctls
//
#define TERA_PCOIP_HDC_IOCTL_KMP_HDC_OPEN        mTERA_PCOIP_HDC_IOCTL_KMP(0)
#define TERA_PCOIP_HDC_IOCTL_KMP_HDC_CLOSE       mTERA_PCOIP_HDC_IOCTL_KMP(1)
#define TERA_PCOIP_HDC_IOCTL_KMP_FEAT_EN         mTERA_PCOIP_HDC_IOCTL_KMP(2)
#define TERA_PCOIP_HDC_IOCTL_KMP_FEAT_STAT       mTERA_PCOIP_HDC_IOCTL_KMP(3)
#define TERA_PCOIP_HDC_IOCTL_KMP_KBD_REPEAT      mTERA_PCOIP_HDC_IOCTL_KMP(4)
#define TERA_PCOIP_HDC_IOCTL_KMP_KBD_LOCK        mTERA_PCOIP_HDC_IOCTL_KMP(5)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_SHAPE_BMP   mTERA_PCOIP_HDC_IOCTL_KMP(6)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_SHAPE       mTERA_PCOIP_HDC_IOCTL_KMP(7)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_POS         mTERA_PCOIP_HDC_IOCTL_KMP(8)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_VIS         mTERA_PCOIP_HDC_IOCTL_KMP(9)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_IDLE_HIDE   mTERA_PCOIP_HDC_IOCTL_KMP(10)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_SPD_GET     mTERA_PCOIP_HDC_IOCTL_KMP(11)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_SPD_SET     mTERA_PCOIP_HDC_IOCTL_KMP(12)
#define TERA_PCOIP_HDC_IOCTL_KMP_LAST_FEAT_STAT  mTERA_PCOIP_HDC_IOCTL_KMP(13)
#define TERA_PCOIP_HDC_IOCTL_KMP_KBD_REPEAT_GET  mTERA_PCOIP_HDC_IOCTL_KMP(14)
#define TERA_PCOIP_HDC_IOCTL_KMP_CUR_POS_IF_NEW  mTERA_PCOIP_HDC_IOCTL_KMP(15)
#define TERA_PCOIP_HDC_IOCTL_KMP_DISP_TOPO_SET   mTERA_PCOIP_HDC_IOCTL_KMP(16)
#define TERA_PCOIP_HDC_IOCTL_KMP_DRIVER_CFG_SET  mTERA_PCOIP_HDC_IOCTL_KMP(17)


// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

