////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     PCoIP Host Software Application Class
///
///     This file defines the PCoIP Host Software application class.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

#include <wx/app.h>
#include <wx/log.h>
#include <wx/config.h>
#include <wx/snglinst.h>

#include "tera_pcoip_agent_gui.h"

// ---- Constants and Types -------------------------------------------------

// --------------------------------------------------------------------------
//  eTERA_PCOIP_DISCONNECT_CAUSE
///     Disconnect reason cause enumeration
//
//  Description:
///     This enumeration defines the various reasons for disconnecting
///     a PCoIP session.  Various managers in the system support specifying
///     the disconnect reason cause.  Ultimately the SSIG BYE handshake uses
///     the disconnect reason cause to inform the peer why the PCoIP session
///     is disconnected.  See TER0904002 for more information.
///
///     The values listed in the enum below are all of the values that can be
///     provided by the host driver (PCoIP Host Software application).
///
typedef enum
{
    TERA_DISCONNECT_CAUSE_HOST_DRIVER_MANUAL_USER_DISCONNECT      = 0x00000200,
    TERA_DISCONNECT_CAUSE_HOST_DRIVER_INCOMPATIBLE_DRIVER_VERSION = 0x00000201,
} eTERA_PCOIP_DISCONNECT_CAUSE;

// Host card types
#define TERA1x00_HOST_CARD          0
#define TERA2240_HOST_CARD          1
#define MAX_TERA_HOST_DEVICE_TYPE   2

// This macro returns the maximum number of monitors supported by a specific
// host card.
#define MAX_MONITORS(host_type)  \
    (((host_type) == TERA2240_HOST_CARD) ? 4 : 2)

// --------------------------------------------------------------------------
//  cTERA_PCOIP_AGENT
///     PCoIP Host Software application
//
//  Description:
///     This class defines the PCoIP Host Software application.
///
class cTERA_PCOIP_AGENT : public wxApp
{

public:

    // --- Public Functions -------------------------------------------------

    cTERA_PCOIP_AGENT(void);

    ~cTERA_PCOIP_AGENT(void);

    cPCOIP_AGENT_GUI& gui(void)
    {
        wxASSERT(m_gui != NULL);

        return *m_gui;
    }

protected:

    // --- Protected Functions ----------------------------------------------

    virtual bool OnInit(void);

    virtual int OnExit(void);

    virtual void OnFatalException(void);

    void disconnect(
        eTERA_PCOIP_DISCONNECT_CAUSE reason);

    void disable_lcur(void);

    INT32 dump_network_cfg(void);

    int is_twinview_enabled(void);

    void init_def_local_filename(
        wxString *cfg_filename);

    bool is_global_config_file_ok(
        const wxString *cfg_filename);

    bool is_local_config_file_ok(
        const wxString *cfg_filename);

    void evt_end_session(
        wxCloseEvent& evt);

    // --- Protected Variables ----------------------------------------------

    cPCOIP_AGENT_GUI        *m_gui;     ///< Main GUI object
    INT                      m_lock_fp; ///< File pointer used to ensure only one
                                        ///< instance of the host SW is running

    DECLARE_EVENT_TABLE()
}; // cTERA_PCOIP_AGENT

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

